declare type SupportKey = "wxhy" | "wxpyq" | "weibo" | "qq";
export declare enum ChannelEnum {
    "wxhy" = 1,
    "wxpyq" = 2,
    "weibo" = 3,
    "qq" = 4
}
export interface ISupportType {
    id: string;
    /**
     * 渠道号
     */
    channel: ChannelEnum;
    /**
     * 图标
     */
    icon: string;
    /**
     * 文案
     */
    text: string;
    /**
     * 点击事件
     */
    onHandle: () => void;
}
export interface IShareParams {
    /**
     * 分享标题
     */
    title: string;
    /**
     * 分享描述
     */
    desc: string;
    /**
     * 分享链接
     * @description
     * 必须为绝对地址
     * @example
     * https://www.baidu.com
     * @default
     * ```javascript
     * location.href
     * ```
     */
    link?: string;
    /**
     * 分享图标
     * @description
     * 必须为绝对地址
     */
    thumbImangeUrl?: string;
    /**
     * 支持的分享平台
     * @description
     * `wxhy`-微信好友
     *
     * `wxpqy`-微信朋友圈
     */
    support?: SupportKey[];
    /**
     * 是否需要开启微信二次分享
     */
    isTwiceShare?: boolean;
}
export declare class Share {
    #private;
    static shareIconStatic: string;
    static supportStatic: SupportKey[];
    /**
     * jsskd 实例对象
     */
    constructor(params: IShareParams);
    /**
     * 更新分享数据
     */
    update(params: IShareParams): void;
    /**
     * 需要分享的平台
     * @returns
     */
    getSupportData: () => ISupportType[];
    toShareWeiXinHY: (config?: Omit<IShareParams, "support">) => void;
    toShareWeiXinPYQ: (config?: Omit<IShareParams, "support">) => void;
    toShareWeiBo(config?: Omit<IShareParams, "support">): void;
    toShareQQ(config?: Omit<IShareParams, "support">): void;
}
export {};
